==> openjdk-src-19.0.1.u10-2-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_fr_CA.java <==
/*
 * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_fr_CA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_gu = "gujarati";
        final Object[][] data = new Object[][] {
            { "sbp", "sangu" },
            { "Olck", "ol chiki" },
            { "pdt", "bas allemand mennonite" },
            { "nyn", "nkole" },
            { "HM", "\u00eeles Heard et McDonald" },
            { "bik", "bicol" },
            { "mwr", "marwari" },
            { "type.ca.islamic-umalqura", "calendrier musulman (calcul\u00e9, Umm al-Qura)" },
            { "den", "slave" },
            { "mwv", "mentawai" },
            { "mgh", "makhuwa-meetto" },
            { "Zsye", "\u00e9moji" },
            { "mgo", "meta\u2019" },
            { "frc", "cajun" },
            { "IC", "\u00eeles Canaries" },
            { "peo", "vieux perse" },
            { "QO", "Oc\u00e9anie lointaine" },
            { "ii", "yi de Sichuan" },
            { "AC", "\u00eele de l\u2019Ascension" },
            { "rar", "rarotonga" },
            { "IM", "\u00eele de Man" },
            { "frp", "franco-proven\u00e7al" },
            { "type.co.eor", "ordre multilingue europ\u00e9en" },
            { "IO", "territoire britannique de l\u2019oc\u00e9an Indien" },
            { "bbj", "ghomala" },
            { "Deva", "devanagari" },
            { "stq", "frison de Saterland" },
            { "Hrkt", "syllabaires japonais" },
            { "njo", "ao naga" },
            { "RE", "la R\u00e9union" },
            { "sdh", "kurde m\u00e9ridional" },
            { "AX", "\u00eeles d\u2019\u00c5land" },
            { "pfl", "palatin" },
            { "sly", "selayar" },
            { "dgr", "tlicho" },
            { "sus", "sosso" },
            { "BV", "\u00eele Bouvet" },
            { "ken", "kenyang" },
            { "smn", "sami d\u2019Inari" },
            { "sei", "seri" },
            { "BY", "B\u00e9larus" },
            { "KG", "Kirghizistan" },
            { "kg", "kongo" },
            { "ListKeyTypePattern", "{0} : {1}" },
            { "CC", "\u00eeles Cocos (Keeling)" },
            { "kl", "kalaallisut" },
            { "SX", "Saint-Martin (Pays-Bas)" },
            { "type.co.reformed", "Ordre de tri r\u00e9form\u00e9" },
            { "CK", "\u00eeles Cook" },
            { "ks", "kashmiri" },
            { "asa", "asou" },
            { "cr", "cri" },
            { "145", "Asie occidentale" },
            { "CX", "\u00eele Christmas" },
            { "TL", "Timor-Leste" },
            { "type.co.searchjl", "Rechercher par consonne initiale en hangeul" },
            { "ebu", "embou" },
            { "goh", "vieux haut-allemand" },
            { "LR", "Lib\u00e9ria" },
            { "esu", "yupik central" },
            { "lu", "luba-katanga" },
            { "nmg", "kwasio" },
            { "sga", "vieil irlandais" },
            { "030", "Asie orientale" },
            { "151", "Europe orientale" },
            { "154", "Europe septentrionale" },
            { "sw_CD", "swahili congolais" },
            { "type.nu.mong", "Chiffres mongols" },
            { "155", "Europe occidentale" },
            { "039", "Europe m\u00e9ridionale" },
            { "type.d0.hwidth", "demi-chasse" },
            { "UM", "\u00eeles mineures \u00e9loign\u00e9es des \u00c9tats-Unis" },
            { "liv", "live" },
            { "MF", "Saint-Martin (France)" },
            { "lzh", "chinois classique" },
            { "MM", "Myanmar" },
            { "MP", "Mariannes du Nord" },
            { "chg", "tchagatay" },
            { "mr", "marathe" },
            { "pau", "palauan" },
            { "tzm", "tamazight" },
            { "type.m0.ungegn", "GENUNG" },
            { "chn", "chinook" },
            { "VA", "Cit\u00e9 du Vatican" },
            { "nds_NL", "bas saxon" },
            { "pro", "ancien occitan" },
            { "Hanb", "hanb" },
            { "VG", "\u00eeles Vierges britanniques" },
            { "VI", "\u00eeles Vierges am\u00e9ricaines" },
            { "type.co.dictionary", "Ordre de tri du dictionnaire" },
            { "type.nu.gujr", "chiffres gujaratis" },
            { "tru", "turoyo" },
            { "ady", "adygu\u00e9" },
            { "NF", "\u00eele Norfolk" },
            { "VN", "Vietnam" },
            { "NG", "Nig\u00e9ria" },
            { "nwc", "newari classique" },
            { "Hans", "id\u00e9ogrammes han simplifi\u00e9s" },
            { "Hant", "id\u00e9ogrammes han traditionnels" },
            { "quc", "k\u2019iche\u2019" },
            { "FK", "\u00eeles Malouines" },
            { "FO", "\u00eeles F\u00e9ro\u00e9" },
            { "type.m0.bgn", "BGN (commission de toponymie des \u00c9tats-Unis)" },
            { "ang", "vieil anglais" },
            { "type.ca.ethiopic-amete-alem", "Calendrier \u00e9thiopien de l\u2019An de gr\u00e2ce" },
            { "gu", metaValue_gu },
            { "pdc", "allemand de Pennsylvanie" },
            { "Gujr", metaValue_gu },
            { "byn", "bilen" },
            { "ckb", "kurde central" },
            { "ksb", "chambala" },
            { "ewo", "ewondo" },
            { "PN", "\u00eeles Pitcairn" },
            { "byv", "medumba" },
            { "type.d0.fwidth", "pleine chasse" },
        };
        return data;
    }
}

==> openjdk-src-23.0.2.u7-1-x86_64.pkg.tar.zst: jdk.localedata/sun/util/resources/cldr/ext/LocaleNames_fr_CA.java <==
/*
 * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.  Oracle designates this
 * particular file as subject to the "Classpath" exception as provided
 * by Oracle in the LICENSE file that accompanied this code.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * COPYRIGHT AND PERMISSION NOTICE
 *
 * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
 * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of the Unicode data files and any associated documentation
 * (the "Data Files") or Unicode software and any associated documentation
 * (the "Software") to deal in the Data Files or Software
 * without restriction, including without limitation the rights to use,
 * copy, modify, merge, publish, distribute, and/or sell copies of
 * the Data Files or Software, and to permit persons to whom the Data Files
 * or Software are furnished to do so, provided that either
 * (a) this copyright and permission notice appear with all copies
 * of the Data Files or Software, or
 * (b) this copyright and permission notice appear in associated
 * Documentation.
 *
 * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
 * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
 * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
 * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
 * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
 *
 * Except as contained in this notice, the name of a copyright holder
 * shall not be used in advertising or otherwise to promote the sale,
 * use or other dealings in these Data Files or Software without prior
 * written authorization of the copyright holder.
 */

package sun.util.resources.cldr.ext;

import sun.util.resources.OpenListResourceBundle;

public class LocaleNames_fr_CA extends OpenListResourceBundle {
    @Override
    protected final Object[][] getContents() {
        final String metaValue_gu = "gujarati";
        final Object[][] data = new Object[][] {
            { "030", "Asie orientale" },
            { "039", "Europe m\u00e9ridionale" },
            { "145", "Asie occidentale" },
            { "151", "Europe orientale" },
            { "154", "Europe septentrionale" },
            { "155", "Europe occidentale" },
            { "AC", "\u00eele de l\u2019Ascension" },
            { "AX", "\u00eeles d\u2019\u00c5land" },
            { "BN", "Brun\u00e9i" },
            { "BV", "\u00eele Bouvet" },
            { "BY", "B\u00e9larus" },
            { "BZ", "B\u00e9lize" },
            { "CC", "\u00eeles Cocos (Keeling)" },
            { "CK", "\u00eeles Cook" },
            { "CX", "\u00eele Christmas" },
            { "FK", "\u00eeles Malouines" },
            { "FO", "\u00eeles F\u00e9ro\u00e9" },
            { "HM", "\u00eeles Heard et McDonald" },
            { "IC", "\u00eeles Canaries" },
            { "IM", "\u00eele de Man" },
            { "KG", "Kirghizistan" },
            { "KN", "Saint\u2011Kitts\u2011et\u2011Nevis" },
            { "LR", "Lib\u00e9ria" },
            { "MF", "Saint-Martin (France)" },
            { "MM", "Myanmar" },
            { "MP", "Mariannes du Nord" },
            { "NF", "\u00eele Norfolk" },
            { "NG", "Nig\u00e9ria" },
            { "PN", "\u00eeles Pitcairn" },
            { "QO", "Oc\u00e9anie lointaine" },
            { "RE", "la R\u00e9union" },
            { "SX", "Saint-Martin (Pays-Bas)" },
            { "TL", "Timor-Leste" },
            { "UM", "\u00eeles mineures \u00e9loign\u00e9es des \u00c9tats-Unis" },
            { "VA", "Cit\u00e9 du Vatican" },
            { "VE", "V\u00e9n\u00e9zu\u00e9la" },
            { "VG", "\u00eeles Vierges britanniques" },
            { "VI", "\u00eeles Vierges am\u00e9ricaines" },
            { "VN", "Vietnam" },
            { "cr", "cri" },
            { "gu", metaValue_gu },
            { "ii", "yi de Sichuan" },
            { "kg", "kongo" },
            { "kl", "kalaallisut" },
            { "ks", "kashmiri" },
            { "lu", "luba-katanga" },
            { "mr", "marathe" },
            { "ady", "adygu\u00e9" },
            { "ang", "vieil anglais" },
            { "asa", "asou" },
            { "bbj", "ghomala" },
            { "bik", "bicol" },
            { "byn", "bilen" },
            { "byv", "medumba" },
            { "chg", "tchagatay" },
            { "chn", "chinook" },
            { "ckb", "kurde central" },
            { "crg", "michif" },
            { "crl", "cri du Nord-Est" },
            { "crr", "algonquin de la Caroline" },
            { "den", "slave" },
            { "dgr", "tlicho" },
            { "ebu", "embou" },
            { "esu", "yupik central" },
            { "ewo", "ewondo" },
            { "frc", "cajun" },
            { "frp", "franco-proven\u00e7al" },
            { "goh", "vieux haut-allemand" },
            { "ken", "kenyang" },
            { "ksb", "chambala" },
            { "liv", "live" },
            { "lzh", "chinois classique" },
            { "mgh", "makhuwa-meetto" },
            { "mgo", "meta\u2019" },
            { "mwr", "marwari" },
            { "mwv", "mentawai" },
            { "njo", "ao naga" },
            { "nmg", "kwasio" },
            { "nwc", "newari classique" },
            { "nyn", "nkole" },
            { "oka", "okanagan" },
            { "pau", "palauan" },
            { "pdc", "allemand de Pennsylvanie" },
            { "pdt", "bas allemand mennonite" },
            { "peo", "vieux perse" },
            { "pfl", "palatin" },
            { "pis", "pidgin" },
            { "pro", "ancien occitan" },
            { "quc", "k\u2019iche\u2019" },
            { "rar", "rarotonga" },
            { "sbp", "sangu" },
            { "sdh", "kurde m\u00e9ridional" },
            { "sei", "seri" },
            { "sga", "vieil irlandais" },
            { "sly", "selayar" },
            { "smn", "sami d\u2019Inari" },
            { "stq", "frison de Saterland" },
            { "sus", "sosso" },
            { "tru", "turoyo" },
            { "tzm", "tamazight" },
            { "Deva", "devanagari" },
            { "Gujr", metaValue_gu },
            { "Hanb", "hanb" },
            { "Hans", "id\u00e9ogrammes han simplifi\u00e9s" },
            { "Hant", "id\u00e9ogrammes han traditionnels" },
            { "Hrkt", "syllabaires japonais" },
            { "Olck", "ol chiki" },
            { "Zsye", "\u00e9moji" },
            { "sw_CD", "swahili congolais" },
            { "nds_NL", "bas saxon" },
            { "type.co.eor", "ordre multilingue europ\u00e9en" },
            { "type.m0.bgn", "BGN (commission de toponymie des \u00c9tats-Unis)" },
            { "type.nu.gujr", "chiffres gujaratis" },
            { "type.nu.mong", "Chiffres mongols" },
            { "type.co.pinyin", "ordre de tri pinyin" },
            { "type.co.stroke", "ordre de tri des traits" },
            { "type.co.zhuyin", "ordre de tri zhuyin" },
            { "type.d0.fwidth", "pleine chasse" },
            { "type.d0.hwidth", "demi-chasse" },
            { "type.m0.ungegn", "GENUNG" },
            { "type.co.big5han", "ordre de tri chinois traditionnel - Big5" },
            { "type.co.searchjl", "Rechercher par consonne initiale en hangeul" },
            { "type.co.gb2312han", "ordre de tri chinois simplifi\u00e9 - GB2312" },
            { "type.co.phonebook", "ordre de tri de l\u2019annuaire" },
            { "ListKeyTypePattern", "{0} : {1}" },
            { "type.co.dictionary", "ordre de tri du dictionnaire" },
            { "type.co.traditional", "ordre de tri traditionnel" },
        };
        return data;
    }
}
